@@ -16,7 +16,7 @@ Usage::
     session_client: PinpointClient = session.client("pinpoint")
     ```
 """
-from mypy_boto3_pinpoint.client import PinpointClient
+from .client import PinpointClient
 
 Client = PinpointClient
 
